References
==========

If you use **genriesz** in academic work, please cite the following papers.

Primary references
------------------

* Masahiro Kato, *Riesz Representer Fitting under Bregman Divergence: A Unified Framework for Debiased Machine Learning*.
  https://arxiv.org/abs/2601.07752

  The arXiv:2601.07752 manuscript consolidates earlier related drafts:

  * https://arxiv.org/abs/2509.22122
  * https://arxiv.org/abs/2510.26783
  * https://arxiv.org/abs/2510.23534

* Masahiro Kato, *Direct Bias-Correction Term Estimation for Propensity Scores and Average Treatment Effect Estimation*.
  https://arxiv.org/abs/2509.22122

* Masahiro Kato, *Nearest Neighbor Matching as Least Squares Density Ratio Estimation and Riesz Regression*.
  https://arxiv.org/abs/2510.24433
